[Datatype-cvs] common/vidrend vidrend.cpp, 1.59, 1.60 vidrendf.cpp, 1.22, 1.23

[Datatype-cvs] common/vidrend vidrend.cpp, 1.59, 1.60 vidrendf.cpp, 1.22, 1.23

ehyche at helixcommunity.org ehyche at helixcommunity.org
Wed May 11 10:55:03 PDT 2005


Update of /cvsroot/datatype/common/vidrend
In directory cvs-new:/tmp/cvs-serv20751

Modified Files:
	vidrend.cpp vidrendf.cpp 
Log Message:
Add IsFirstKeyFramePacket() method and
change OnTimeSync logging statement to level 3.
CR ping at real.com


Index: vidrend.cpp
===================================================================
RCS file: /cvsroot/datatype/common/vidrend/vidrend.cpp,v
retrieving revision 1.59
retrieving revision 1.60
diff -u -d -r1.59 -r1.60
--- vidrend.cpp	5 May 2005 16:15:08 -0000	1.59
+++ vidrend.cpp	11 May 2005 17:55:01 -0000	1.60
@@ -1156,7 +1156,7 @@
 //
 STDMETHODIMP CVideoRenderer::OnTimeSync(ULONG32 ulTime)
 {
-    HXLOGL4(HXLOG_VIDE, "CVideoRenderer::OnTimeSync(%lu)", ulTime);
+    HXLOGL3(HXLOG_VIDE, "CVideoRenderer::OnTimeSync(%lu)", ulTime);
     m_pTimeSyncSmoother->OnTimeSync(ulTime);
 
     if (m_bSchedulerStartRequested)

Index: vidrendf.cpp
===================================================================
RCS file: /cvsroot/datatype/common/vidrend/vidrendf.cpp,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -d -r1.22 -r1.23
--- vidrendf.cpp	27 Apr 2005 13:57:38 -0000	1.22
+++ vidrendf.cpp	11 May 2005 17:55:01 -0000	1.23
@@ -385,26 +385,20 @@
             // Since we'll be taking them off the head as well,
             // then this provides the reversal
             m_pReversalQueue->AddHead((void*) pPayloadData);
-            // Is this a keyframe packet?
-            if (IsKeyFramePacket(pPayloadData))
+            // Is this the first keyframe packet?
+            if (IsFirstKeyFramePacket(pPayloadData))
             {
-                // To determine if it's the FIRST packet of
-                // the keyframe (in forward order), then we
-                // will look for the HX_ASM_SWITCH_ON flag
-                if (pPayloadData->GetASMFlags() & HX_ASM_SWITCH_ON)
+                HXLOGL4(HXLOG_VIDE, "Dumping %lu packets in reversal queue to assembler", m_pReversalQueue->GetCount());
+                // This is the first packet of a keyframe
+                // (in normal forward order), so we can now
+                // pass all the packets in the reversal queue
+                // into the assembler.
+                while (m_pReversalQueue->GetCount() > 0)
                 {
-                    HXLOGL4(HXLOG_VIDE, "Dumping %lu packets in reversal queue to assembler", m_pReversalQueue->GetCount());
-                    // This is the first packet of a keyframe
-                    // (in normal forward order), so we can now
-                    // pass all the packets in the reversal queue
-                    // into the assembler.
-                    while (m_pReversalQueue->GetCount() > 0)
+                    IHXPacket* pPacket = (IHXPacket*) m_pReversalQueue->RemoveHead();
+                    if (pPacket)
                     {
-                        IHXPacket* pPacket = (IHXPacket*) m_pReversalQueue->RemoveHead();
-                        if (pPacket)
-                        {
-                            bRet = _Enqueue(pPacket);
-                        }
+                        bRet = _Enqueue(pPacket);
                     }
                 }
             }




More information about the Datatype-cvs mailing list
 

Site Map   |   Terms of Use   |   Privacy Policy   |   Contact Us

Copyright © 1995-2007 RealNetworks, Inc. All rights reserved. RealNetworks and Helix are trademarks of RealNetworks.
All other trademarks or registered trademarks are the property of their respective holders.